famous_types

Function famous_types 

pub(super) fn famous_types<'a, 'lt, 'db, DB: HirDatabase>(
    ctx: &'a TermSearchCtx<'db, DB>,
    _defs: &'a FxHashSet<ScopeDef>,
    lookup: &'lt mut LookupTable<'db>,
) -> impl Iterator<Item = Expr<'db>> + use<'a, 'db, 'lt, DB>
Famous types tactic

Attempts different values of well known types such as true or false.

Updates lookup by new types reached and returns iterator that yields elements that unify with goal.

Note that there is no point of calling it iteratively as the output is always the same

Arguments

  • ctx - Context for the term search
  • defs - Set of items in scope at term search target location
  • lookup - Lookup table for types